pub enum HumanCliError {
Store(StoreError),
Io(Error),
InvalidAnswer(String),
NotPending(String),
}Expand description
Errors of the collection channel.
Variants
Store(StoreError)
Reading the ledger failed.
Io(Error)
Terminal I/O failed.
InvalidAnswer(String)
The answer could not be interpreted for the request’s mode.
NotPending(String)
No pending request with that id exists on the ledger.